#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['apiera']

package_data = \
{'': ['*']}

install_requires = \
['click==7.1.2',
 'Cython==0.29.21',
 'h11==0.9.0',
 'starlette==0.13.8',
 'uvicorn==0.11.8',
 'websockets==8.1']

setup(name='apiera',
      version='0.0.11',
      description='Apiera framework, high performance',
      author='Jérôme Krell',
      author_email='jerome.krell@bluewin.ch',
      url='https://github.com/JeromeK13/hapi',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
     )
